==> amarok_2.9.0.orig.tar.xz: amarok-2.9.0/src/core-impl/collections/audiocd/handler/AudioCdHandler.h <==
/****************************************************************************************
 * Copyright (c) 2009 Nikolaj Hald Nielsen <nhn@kde.org>                                *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/
 
#ifndef AUDIOCDHANDLER_H
#define AUDIOCDHANDLER_H

#include "core-impl/collections/mediadevicecollection/handler/MediaDeviceHandler.h"

namespace Meta {

/**
A hander class for the AudioCd collection

	@author 
*/
class AudioCdHandler : public MediaDeviceHandler
{
public:
    AudioCdHandler( QObject *parent );

    ~AudioCdHandler();

    virtual void init();
    virtual bool isWritable() const { return false; }
    virtual QString prettyName() const;

};

}

#endif

==> amarok_3.2.2.orig.tar.xz: amarok-3.2.2/src/core-impl/collections/audiocd/handler/AudioCdHandler.h <==
/****************************************************************************************
 * Copyright (c) 2009 Nikolaj Hald Nielsen <nhn@kde.org>                                *
 *                                                                                      *
 * This program is free software; you can redistribute it and/or modify it under        *
 * the terms of the GNU General Public License as published by the Free Software        *
 * Foundation; either version 2 of the License, or (at your option) any later           *
 * version.                                                                             *
 *                                                                                      *
 * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
 * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
 *                                                                                      *
 * You should have received a copy of the GNU General Public License along with         *
 * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
 ****************************************************************************************/
 
#ifndef AUDIOCDHANDLER_H
#define AUDIOCDHANDLER_H

#include "core-impl/collections/mediadevicecollection/handler/MediaDeviceHandler.h"

namespace Meta {

/**
A hander class for the AudioCd collection

	@author 
*/
class AudioCdHandler : public MediaDeviceHandler
{
public:
    explicit AudioCdHandler( QObject *parent );

    ~AudioCdHandler() override;

    void init() override;
    bool isWritable() const override { return false; }
    QString prettyName() const override;

};

}

#endif
